@@ -256,10 +256,6 @@ class JestApp(ProcessTestApp):
 
     test_config = Dict(dict(foo='bar'))
 
-    serverapp_config = {
-        "open_browser": False
-    }
-
     @deprecated(removed_version=4)
     def get_command(self):
         """Get the command to run"""
